@@ -16,52 +16,59 @@
 
 #include "kfontsizeaction.h"
 
+#include "kselectaction_p.h"
+
 #include "loggingcategory.h"
 
 #include <QFontDatabase>
 
-class Q_DECL_HIDDEN KFontSizeAction::Private
+class KFontSizeActionPrivate : public KSelectActionPrivate
 {
+    Q_DECLARE_PUBLIC(KFontSizeAction)
+
 public:
-    Private(KFontSizeAction *parent)
-        : q(parent)
+    KFontSizeActionPrivate(KFontSizeAction *qq)
+        : KSelectActionPrivate(qq)
     {
     }
 
     void init();
-
-    KFontSizeAction *q;
 };
 
 // BEGIN KFontSizeAction
 KFontSizeAction::KFontSizeAction(QObject *parent)
-    : KSelectAction(parent),
-      d(new Private(this))
+    : KSelectAction(*new KFontSizeActionPrivate(this), parent)
 {
+    Q_D(KFontSizeAction);
+
     d->init();
 }
 
 KFontSizeAction::KFontSizeAction(const QString &text, QObject *parent)
-    : KSelectAction(text, parent),
-      d(new Private(this))
+    : KSelectAction(*new KFontSizeActionPrivate(this), parent)
 {
+    Q_D(KFontSizeAction);
+
+    setText(text);
     d->init();
 }
 
 KFontSizeAction::KFontSizeAction(const QIcon &icon, const QString &text, QObject *parent)
-    : KSelectAction(icon, text, parent),
-      d(new Private(this))
+    : KSelectAction(*new KFontSizeActionPrivate(this), parent)
 {
+    Q_D(KFontSizeAction);
+
+    setIcon(icon);
+    setText(text);
     d->init();
 }
 
-KFontSizeAction::~KFontSizeAction()
-{
-    delete d;
-}
+KFontSizeAction::~KFontSizeAction() = default;
 
-void KFontSizeAction::Private::init()
+void KFontSizeActionPrivate::init()
 {
+    Q_Q(KFontSizeAction);
+
     q->setEditable(true);
     QFontDatabase fontDB;
     const QList<int> sizes = fontDB.standardSizes();
@@ -106,7 +113,7 @@ void KFontSizeAction::setFontSize(int size)
         // Sort the list
         std::sort(lst.begin(), lst.end());
         clear();
-        for (int it : qAsConst(lst)) {
+        for (int it : std::as_const(lst)) {
             QAction *const action = addAction(QString::number(it));
             if (it == size) {
                 setCurrentAction(action);
@@ -125,7 +132,6 @@ int KFontSizeAction::fontSize() const
 
 void KFontSizeAction::actionTriggered(QAction *action)
 {
-    emit fontSizeChanged(action->text().toInt());
+    Q_EMIT fontSizeChanged(action->text().toInt());
     KSelectAction::actionTriggered(action);
 }
-
